=======
Compose
=======

Python objects
==============

.. automodule:: bodhi.messages.schemas.compose
   :exclude-members: body_schema, __module__
   :members:
   :show-inheritance:
   :special-members:
   :undoc-members:


JSON schemas
============

.. include:: ../../generated/compose.rst
